@@ -1,13 +1,13 @@
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::Lib;
-# git description: v0.001-3-g78dbcce
+# git description: v0.002-5-g1c4b790
 
 BEGIN {
   $BenchmarkAnything::Storage::Frontend::Lib::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Basic functions to access a BenchmarkAnything store
-$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.002';
+$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.003';
 use Scalar::Util 'reftype';
 
 
@@ -21,7 +21,9 @@ sub new
 
 sub _format_flat_inner_scalar
 {
-    my ($self, $result) = @_;
+    my ($self, $result, $opt) = @_;
+
+    no warnings 'uninitialized';
 
     return "$result";
 }
@@ -30,34 +32,40 @@ sub _format_flat_inner_array
 {
         my ($self, $result, $opt) = @_;
 
+        no warnings 'uninitialized';
+
         return
          join($opt->{separator},
               map {
                    # only SCALARS allowed (where reftype returns undef)
-                   die "dpath: unsupported innermost nesting (".reftype($_).") for 'flat' output.\n" if defined reftype($_);
+                   die "benchmarkanything: unsupported innermost nesting (".reftype($_).") for 'flat' output.\n" if defined reftype($_);
                    "".$_
                   } @$result);
 }
 
 sub _format_flat_inner_hash
 {
-        my ($c, $result, $opt) = @_;
+        my ($self, $result, $opt) = @_;
+
+        no warnings 'uninitialized';
 
         return
          join($opt->{separator},
               map { my $v = $result->{$_};
                     # only SCALARS allowed (where reftype returns undef)
-                    die "dpath: unsupported innermost nesting (".reftype($v).") for 'flat' output.\n" if defined reftype($v);
+                    die "benchmarkanything: unsupported innermost nesting (".reftype($v).") for 'flat' output.\n" if defined reftype($v);
                     "$_=".$v
                   } keys %$result);
 }
 
 sub _format_flat_outer
 {
-        my ($c, $result, $opt) = @_;
+        my ($self, $result, $opt) = @_;
+
+        no warnings 'uninitialized';
 
         my $output = "";
-        die "dpath: can not flatten data structure (undef) - try other output format.\n" unless defined $result;
+        die "benchmarkanything: can not flatten data structure (undef) - try other output format.\n" unless defined $result;
 
         my $A = ""; my $B = ""; if ($opt->{fb}) { $A = "["; $B = "]" }
         my $fi = $opt->{fi};
@@ -70,16 +78,16 @@ sub _format_flat_outer
                         my $entry  = $result->[$i];
                         my $prefix = $fi ? "$i:" : "";
                         if (!defined reftype $entry) { # SCALAR
-                                $output .= $prefix.$A._format_flat_inner_scalar($c, $entry)."$B\n";
+                                $output .= $prefix.$A.$self->_format_flat_inner_scalar($entry, $opt)."$B\n";
                         }
                         elsif (reftype $entry eq 'ARRAY') {
-                                $output .= $prefix.$A._format_flat_inner_array($c, $entry)."$B\n";
+                                $output .= $prefix.$A.$self->_format_flat_inner_array($entry, $opt)."$B\n";
                         }
                         elsif (reftype $entry eq 'HASH') {
-                                $output .= $prefix.$A._format_flat_inner_hash($c, $entry)."$B\n";
+                                $output .= $prefix.$A.$self->_format_flat_inner_hash($entry, $opt)."$B\n";
                         }
                         else {
-                                die "dpath: can not flatten data structure (".reftype($entry).").\n";
+                                die "benchmarkanything: can not flatten data structure (".reftype($entry).").\n";
                         }
                 }
         }
@@ -88,34 +96,37 @@ sub _format_flat_outer
                 foreach my $key (@keys) {
                         my $entry = $result->{$key};
                         if (!defined reftype $entry) { # SCALAR
-                                $output .= "$key:"._format_flat_inner_scalar($c, $entry)."\n";
+                                $output .= "$key:".$self->_format_flat_inner_scalar($entry, $opt)."\n";
                         }
                         elsif (reftype $entry eq 'ARRAY') {
-                                $output .= "$key:"._format_flat_inner_array($c, $entry)."\n";
+                                $output .= "$key:".$self->_format_flat_inner_array($entry, $opt)."\n";
                         }
                         elsif (reftype $entry eq 'HASH') {
-                                $output .= "$key:"._format_flat_inner_hash($c, $entry)."\n";
+                                $output .= "$key:".$self->_format_flat_inner_hash($entry, $opt)."\n";
                         }
                         else {
-                                die "dpath: can not flatten data structure (".reftype($entry).").\n";
+                                die "benchmarkanything: can not flatten data structure (".reftype($entry).").\n";
                         }
                 }
         }
         else {
-                die "dpath: can not flatten data structure (".reftype($result).") - try other output format.\n";
+                die "benchmarkanything: can not flatten data structure (".reftype($result).") - try other output format.\n";
         }
 
         return $output;
 }
 
-
 sub _format_flat
 {
-        my ($c, $resultlist, $opt) = @_;
+        my ($self, $result, $opt) = @_;
+
+        # ensure array container
+        # for consistent output in 'getpoint' and 'search'
+        my $resultlist = reftype($result) eq 'ARRAY' ? $result : [$result];
 
         my $output = "";
         $opt->{separator} = ";" unless defined $opt->{separator};
-        $output .= _format_flat_outer($c, $_) foreach @$resultlist;
+        $output .= $self->_format_flat_outer($resultlist, $opt);
         return $output;
 }
 
@@ -155,7 +166,7 @@ sub _output_format
                 $output .= $xs->XMLout($data, AttrIndent => 1, KeepRoot => 1);
         }
         elsif ($outtype eq "flat") {
-                $output .= $self->_format_flat( $data );
+                $output .= $self->_format_flat( $data, $opt );
         }
         else
         {
